import sys

from zope.tales.engine import Engine
from zope.pagetemplate.pagetemplate import PageTemplate

from zope.contentprovider.tales import TALESProviderExpression


def run():
    if len(sys.argv) < 2:
        print "zptlint file [files...]"
        sys.exit(1)
    else:
        for arg in sys.argv[1:]:
            test(arg)


def registerTALESExpressionType(name, handler):
    Engine.registerType(name, handler)


def test(file):
    registerTALESExpressionType('provider', TALESProviderExpression)
    raw_data = open(file, 'r').read()
    pt = PageTemplate()
    pt.write(raw_data)
    if pt._v_errors:
        print "*** Error in:", file
        for error in pt._v_errors[1:]:
            formatted = error.replace('\n', ' ')
            linepos = formatted.rfind(', at line')
            if linepos != -1:
                formatted, formatted2 = (
                    formatted[:linepos], formatted[linepos:])
            else:
                formatted2 = ''
            print '    ', formatted
            print '    ', formatted2
        print



from setuptools import setup, find_packages

import os


version = '0.2'


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()


long_description = (
        read('README.txt')
        + '\n' +
        read('CHANGES.txt'))

setup(name='zptlint',
      version=version,
      description="Utility to debug Zope Page Templates",
      long_description=long_description,
      classifiers=[
        "Framework :: Zope2",
        "Framework :: Zope3",
      ],
      keywords='zope',
      author='Balazs Ree',
      author_email='ree@ree.hu',
      url='http://trac.gotcha.python-hosting.com/file/bubblenet/pythoncode/'
          'zptlint/README.txt?format=txt',
      license='GPL',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      include_package_data=True,
      zip_safe=True,
      install_requires=[
          'zope.pagetemplate',
          'zope.contentprovider',
          # mentioned here because not mentioned in zope.pagetemplate <= 3.5.0
          'zope.traversing',
          'RestrictedPython',
      ],
      entry_points={
        'console_scripts': [
            'zptlint = zptlint:run',
            ],
        },
      )
